==> dpsutil-1.1.1.tar.gz: dpsutil-1.1.1/dpsutil/compression/compression.py <==
import pickle
import blosc
import numpy

COMPRESS_FASTEST = 0
COMPRESS_BEST = 1

SPLIT_BYTES = b"<s<p>l>"


def compress(data: bytes, compress_type=COMPRESS_FASTEST, nthreads=blosc.ncores) -> bytes:
    assert type(data) is bytes
    blosc.set_nthreads(nthreads)

    compressor = "lz4" if compress_type == COMPRESS_FASTEST else "zstd"
    level = 1 if compress_type == COMPRESS_FASTEST else 5
    return blosc.compress(data, cname=compressor, clevel=level)


def decompress(binary: bytes) -> bytes:
    assert type(binary) is bytes
    return blosc.decompress(binary)


def compress_ndarray(vectors: numpy.ndarray, compress_type=COMPRESS_FASTEST, nthreads=blosc.ncores) -> bytes:
    assert type(vectors) is numpy.ndarray
    blosc.set_nthreads(nthreads)

    compressor = "lz4" if compress_type == COMPRESS_FASTEST else "zstd"
    level = 1 if compress_type == COMPRESS_FASTEST else 5
    buffer = blosc.compress_ptr(vectors.__array_interface__['data'][0], vectors.size,
                                typesize=max(1, min(255, vectors.dtype.itemsize)),
                                clevel=level, cname=compressor, shuffle=blosc.BITSHUFFLE)
    return pickle.dumps([buffer, vectors.dtype, vectors.shape])


def decompress_ndarray(binary: bytes) -> numpy.ndarray:
    assert type(binary) is bytes

    buffer, dtype, shape = pickle.loads(binary)
    arr = numpy.empty(shape, dtype)
    blosc.decompress_ptr(buffer, arr.__array_interface__['data'][0])
    return arr


def compress_list(array: list, compress_type=COMPRESS_FASTEST, nthreads=blosc.ncores) -> bytes:
    assert type(array) is list
    return compress_ndarray(numpy.array(array), compress_type=compress_type, nthreads=nthreads)


def decompress_list(buffer: bytes):
    assert type(buffer) is bytes
    return decompress_ndarray(buffer).tolist()


__all__ = ['compress', 'decompress', 'compress_ndarray', 'decompress_ndarray', 'compress_list', 'decompress_list',
           'COMPRESS_BEST', 'COMPRESS_FASTEST']

==> dpsutil-1.1.19.tar.gz: dpsutil-1.1.19/dpsutil/compression/compression.py <==
import pickle
import blosc
import numpy

COMPRESS_FASTEST = 0
COMPRESS_BEST = 1

SPLIT_BYTES = b"<s<p>l>"


def compress(data: bytes, compress_type=COMPRESS_FASTEST, nthreads=blosc.ncores) -> bytes:
    assert type(data) is bytes
    blosc.set_nthreads(nthreads)

    compressor = "lz4" if compress_type == COMPRESS_FASTEST else "zstd"
    level = 1 if compress_type == COMPRESS_FASTEST else 5
    return blosc.compress(data, cname=compressor, clevel=level)


def decompress(binary: bytes) -> bytes:
    assert type(binary) is bytes
    return blosc.decompress(binary)


def compress_ndarray(vectors: numpy.ndarray, compress_type=COMPRESS_FASTEST, nthreads=blosc.ncores) -> bytes:
    assert type(vectors) is numpy.ndarray
    blosc.set_nthreads(nthreads)

    compressor = "lz4" if compress_type == COMPRESS_FASTEST else "zstd"
    level = 1 if compress_type == COMPRESS_FASTEST else 5
    buffer = blosc.compress_ptr(vectors.__array_interface__['data'][0], vectors.size,
                                typesize=max(1, min(255, vectors.dtype.itemsize)),
                                clevel=level, cname=compressor, shuffle=blosc.BITSHUFFLE)
    return pickle.dumps([buffer, vectors.dtype, vectors.shape])


def decompress_ndarray(binary: bytes, output_array=None) -> numpy.ndarray:
    assert type(binary) is bytes
    assert type(output_array) is numpy.ndarray

    buffer, dtype, shape = pickle.loads(binary)
    if not output_array:
        output_array = numpy.empty(shape, dtype)

    assert output_array.shape == shape, "Array output's shape is't same as compressed array."

    blosc.decompress_ptr(buffer, output_array.__array_interface__['data'][0])
    return output_array


def compress_list(array: list, compress_type=COMPRESS_FASTEST, nthreads=blosc.ncores) -> bytes:
    assert type(array) is list
    return compress(pickle.dumps(array), compress_type=compress_type, nthreads=nthreads)


def decompress_list(buffer: bytes):
    assert type(buffer) is bytes
    return pickle.loads(decompress(buffer))


__all__ = ['compress', 'decompress', 'compress_ndarray', 'decompress_ndarray', 'compress_list', 'decompress_list',
           'COMPRESS_BEST', 'COMPRESS_FASTEST']
